@@ -160,6 +160,7 @@ pub enum CheckErrors {
 
     WriteAttemptedInReadOnly,
     AtBlockClosureMustBeReadOnly,
+    CircularContractDependency(String),
 }
 
 #[derive(Debug, PartialEq)]
@@ -395,6 +396,7 @@ impl DiagnosableError for CheckErrors {
             },
             CheckErrors::UncheckedIntermediaryResponses => format!("intermediary responses in consecutive statements must be checked"),
             CheckErrors::CostComputationFailed(s) => format!("contract cost computation failed: {}", s),
+            CheckErrors::CircularContractDependency(contracts) => format!("circular dependency between contracts: {}", contracts),
         }
     }
 
