@@ -1,7 +1,8 @@
+use std::collections::HashMap;
 use std::collections::{btree_map::Entry, BTreeMap, BTreeSet};
 
 use crate::analysis::annotation::{Annotation, AnnotationKind};
-use crate::analysis::dependency_detector::DependencyDetector;
+use crate::analysis::ast_dependency_detector::ASTDependencyDetector;
 use crate::analysis::{self, AnalysisPass as REPLAnalysisPass};
 use crate::clarity;
 use crate::clarity::analysis::{types::AnalysisPass, ContractAnalysis};
@@ -175,6 +176,62 @@ impl ClarityInterpreter {
         Ok(result)
     }
 
+    pub fn run_ast(
+        &mut self,
+        mut ast: ContractAST,
+        snippet: String,
+        contract_identifier: QualifiedContractIdentifier,
+        cost_track: bool,
+        debug: bool,
+        coverage_reporter: Option<TestCoverageReport>,
+    ) -> Result<ExecutionResult, Vec<Diagnostic>> {
+        let (annotations, mut diagnostics) = self.collect_annotations(&ast, &snippet);
+
+        let (analysis, mut analysis_diagnostics) =
+            match self.run_analysis(contract_identifier.clone(), &mut ast, &annotations) {
+                Ok((analysis, diagnostics)) => (analysis, diagnostics),
+                Err((_, Some(diagnostic), _)) => {
+                    diagnostics.push(diagnostic);
+                    return Err(diagnostics);
+                }
+                Err(_) => return Err(diagnostics),
+            };
+        diagnostics.append(&mut analysis_diagnostics);
+
+        let mut result = match self.execute(
+            contract_identifier,
+            &mut ast,
+            snippet,
+            analysis,
+            cost_track,
+            debug,
+            coverage_reporter,
+        ) {
+            Ok(result) => result,
+            Err((_, Some(diagnostic), _)) => {
+                diagnostics.push(diagnostic);
+                return Err(diagnostics);
+            }
+            Err((e, _, _)) => {
+                diagnostics.push(Diagnostic {
+                    level: Level::Error,
+                    message: format!("Runtime Error: {}", e),
+                    spans: vec![],
+                    suggestion: None,
+                });
+                return Err(diagnostics);
+            }
+        };
+
+        result.diagnostics = diagnostics;
+
+        // todo: instead of just returning the value, we should be returning:
+        // - value
+        // - execution cost
+        // - events emitted
+        Ok(result)
+    }
+
     pub fn detect_dependencies(
         &mut self,
         contract_id: String,
@@ -188,21 +245,15 @@ impl ClarityInterpreter {
             return Err("error parsing source".to_string());
         }
 
-        let mut contract_analysis = ContractAnalysis::new(
-            contract_id.clone(),
-            ast.expressions,
-            LimitedCostTracker::new_free(),
-        );
-        let mut analysis_db = AnalysisDatabase::new(&mut self.datastore);
-        match DependencyDetector::run_pass(
-            &mut contract_analysis,
-            &mut analysis_db,
-            &vec![],
-            &self.repl_settings.analysis,
-        ) {
-            Ok(_) => Ok(contract_analysis.dependencies),
-            Err(e) => Err(format!("{:?}", e)),
-        }
+        let mut contract_map = HashMap::new();
+        contract_map.insert(contract_id.clone(), ast);
+        let mut all_dependencies =
+            ASTDependencyDetector::detect_dependencies(&contract_map, &BTreeMap::new());
+        let dependencies = match all_dependencies.remove(&contract_id) {
+            Some(mut dependencies_set) => dependencies_set.drain().collect(),
+            None => vec![],
+        };
+        Ok(dependencies)
     }
 
     pub fn build_ast(
@@ -662,12 +713,12 @@ https://github.com/hirosystems/clarinet/issues/new/choose"#
             return Ok(execution_result);
         }
 
-        let mut analysis_db = AnalysisDatabase::new(&mut self.datastore);
-        analysis_db.begin();
-        analysis_db
-            .insert_contract(&contract_identifier, &contract_analysis)
-            .unwrap();
-        analysis_db.commit();
+        {
+            let mut analysis_db = AnalysisDatabase::new(&mut self.datastore);
+            let _ = analysis_db
+                .execute(|db| db.insert_contract(&contract_identifier, &contract_analysis))
+                .expect("Unable to save data");
+        }
 
         Ok(execution_result)
     }
